==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterEnvoyConfigObjectMatchClusterFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterEnvoyConfigObjectMatchClusterFluent<A extends EnvoyFilterEnvoyConfigObjectMatchClusterFluent<A>> extends BaseFluent<A>{
  public EnvoyFilterEnvoyConfigObjectMatchClusterFluent() {
  }
  public EnvoyFilterEnvoyConfigObjectMatchClusterFluent(EnvoyFilterEnvoyConfigObjectMatchCluster instance) {
    instance = (instance != null ? instance : new EnvoyFilterEnvoyConfigObjectMatchCluster());

    if (instance != null) {
      this.withCluster(instance.getCluster());
      this.withCluster(instance.getCluster());
    }
  }
  private EnvoyFilterClusterMatchBuilder cluster;
  public EnvoyFilterClusterMatch buildCluster() {
    return this.cluster!=null ?this.cluster.build():null;
  }
  public A withCluster(EnvoyFilterClusterMatch cluster) {
    _visitables.get("cluster").remove(this.cluster);
    if (cluster!=null){ this.cluster= new EnvoyFilterClusterMatchBuilder(cluster); _visitables.get("cluster").add(this.cluster);} else { this.cluster = null; _visitables.get("cluster").remove(this.cluster); } return (A) this;
  }
  public boolean hasCluster() {
    return this.cluster != null;
  }
  public A withNewCluster(String name,Integer portNumber,String service,String subset) {
    return (A)withCluster(new EnvoyFilterClusterMatch(name, portNumber, service, subset));
  }
  public ClusterNested<A> withNewCluster() {
    return new ClusterNested(null);
  }
  public ClusterNested<A> withNewClusterLike(EnvoyFilterClusterMatch item) {
    return new ClusterNested(item);
  }
  public ClusterNested<A> editCluster() {
    return withNewClusterLike(java.util.Optional.ofNullable(buildCluster()).orElse(null));
  }
  public ClusterNested<A> editOrNewCluster() {
    return withNewClusterLike(java.util.Optional.ofNullable(buildCluster()).orElse(new EnvoyFilterClusterMatchBuilder().build()));
  }
  public ClusterNested<A> editOrNewClusterLike(EnvoyFilterClusterMatch item) {
    return withNewClusterLike(java.util.Optional.ofNullable(buildCluster()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterEnvoyConfigObjectMatchClusterFluent that = (EnvoyFilterEnvoyConfigObjectMatchClusterFluent) o;
    if (!java.util.Objects.equals(cluster, that.cluster)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cluster,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (cluster != null) { sb.append("cluster:"); sb.append(cluster); }
    sb.append("}");
    return sb.toString();
  }
  public class ClusterNested<N> extends EnvoyFilterClusterMatchFluent<ClusterNested<N>> implements Nested<N>{
    ClusterNested(EnvoyFilterClusterMatch item) {
      this.builder = new EnvoyFilterClusterMatchBuilder(this, item);
    }
    EnvoyFilterClusterMatchBuilder builder;
    public N and() {
      return (N) EnvoyFilterEnvoyConfigObjectMatchClusterFluent.this.withCluster(builder.build());
    }
    public N endCluster() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterEnvoyConfigObjectMatchClusterFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class EnvoyFilterEnvoyConfigObjectMatchClusterFluent<A extends EnvoyFilterEnvoyConfigObjectMatchClusterFluent<A>> extends BaseFluent<A>{
  public EnvoyFilterEnvoyConfigObjectMatchClusterFluent() {
  }
  
  public EnvoyFilterEnvoyConfigObjectMatchClusterFluent(EnvoyFilterEnvoyConfigObjectMatchCluster instance) {
    this.copyInstance(instance);
  }
  private EnvoyFilterClusterMatchBuilder cluster;
  
  protected void copyInstance(EnvoyFilterEnvoyConfigObjectMatchCluster instance) {
    instance = (instance != null ? instance : new EnvoyFilterEnvoyConfigObjectMatchCluster());
  
    if (instance != null) {
        this.withCluster(instance.getCluster());
        this.withCluster(instance.getCluster());
      }
  }
  
  public EnvoyFilterClusterMatch buildCluster() {
    return this.cluster!=null ?this.cluster.build():null;
  }
  
  public A withCluster(EnvoyFilterClusterMatch cluster) {
    _visitables.get("cluster").remove(this.cluster);
    if (cluster!=null){ this.cluster= new EnvoyFilterClusterMatchBuilder(cluster); _visitables.get("cluster").add(this.cluster);} else { this.cluster = null; _visitables.get("cluster").remove(this.cluster); } return (A) this;
  }
  
  public boolean hasCluster() {
    return this.cluster != null;
  }
  
  public A withNewCluster(String name,Integer portNumber,String service,String subset) {
    return (A)withCluster(new EnvoyFilterClusterMatch(name, portNumber, service, subset));
  }
  
  public ClusterNested<A> withNewCluster() {
    return new ClusterNested(null);
  }
  
  public ClusterNested<A> withNewClusterLike(EnvoyFilterClusterMatch item) {
    return new ClusterNested(item);
  }
  
  public ClusterNested<A> editCluster() {
    return withNewClusterLike(java.util.Optional.ofNullable(buildCluster()).orElse(null));
  }
  
  public ClusterNested<A> editOrNewCluster() {
    return withNewClusterLike(java.util.Optional.ofNullable(buildCluster()).orElse(new EnvoyFilterClusterMatchBuilder().build()));
  }
  
  public ClusterNested<A> editOrNewClusterLike(EnvoyFilterClusterMatch item) {
    return withNewClusterLike(java.util.Optional.ofNullable(buildCluster()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterEnvoyConfigObjectMatchClusterFluent that = (EnvoyFilterEnvoyConfigObjectMatchClusterFluent) o;
    if (!java.util.Objects.equals(cluster, that.cluster)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(cluster,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (cluster != null) { sb.append("cluster:"); sb.append(cluster); }
    sb.append("}");
    return sb.toString();
  }
  public class ClusterNested<N> extends EnvoyFilterClusterMatchFluent<ClusterNested<N>> implements Nested<N>{
    ClusterNested(EnvoyFilterClusterMatch item) {
      this.builder = new EnvoyFilterClusterMatchBuilder(this, item);
    }
    EnvoyFilterClusterMatchBuilder builder;
    
    public N and() {
      return (N) EnvoyFilterEnvoyConfigObjectMatchClusterFluent.this.withCluster(builder.build());
    }
    
    public N endCluster() {
      return and();
    }
    
  
  }

}
